from simpleicons.icon import Icon
gitter_icon= Icon(
    title="Gitter",
    slug="gitter",
    hex="ED1965",
    source="https://gitter.im/",
    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>Gitter</title><path d="M8.501 4.001H10.5V24H8.501V4.001zm6.999 0V24h-2V4.001h2zM3.5 0h2.001v15H3.5V0zm15 4.001h2V15h-2V4.001z"/></svg>""",
    guidelines=None,
    license=None,
)
