from simpleicons.icon import Icon
abletonlive_icon= Icon(
    title="Ableton Live",
    slug="abletonlive",
    hex="000000",
    source="https://www.ableton.com/en/legal/branding-trademark-guidelines/",
    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>Ableton Live</title><path d="M0 6.4v11.2h1.6V6.4zm3.2 0v11.2h1.6V6.4zm3.2 0v11.2H8V6.4zm3.2 0v11.2h1.6V6.4zm3.2 0V8H24V6.4zm0 3.2v1.6H24V9.6zm0 3.2v1.6H24v-1.6zm0 3.2v1.6H24V16z"/></svg>""",
    guidelines=None,
    license=None,
)
