from simpleicons.icon import Icon
marketo_icon= Icon(
    title="Marketo",
    slug="marketo",
    hex="5C4C9F",
    source="https://www.marketo.com/",
    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>Marketo</title><path d="M16.146 0v24l6.134-4.886V3.334zM13.293 18.758l-4.939 2.157V2.086l4.939 1.462zM1.721 18.205l3.78-.999V5.188l-3.762-.606z"/></svg>""",
    guidelines=None,
    license=None,
)
