from simpleicons.icon import Icon
mcafee_icon= Icon(
    title="McAfee",
    slug="mcafee",
    hex="C01818",
    source="https://www.mcafee.com/enterprise/en-us/about/newsroom/product-images.html",
    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>McAfee</title><path d="M12 4.8233L1.5793 0v19.1767L12 24l10.4207-4.8233V0zm6.172 11.626l-6.143 2.8428-6.1438-2.8429V6.6894l6.1439 2.8418 6.1429-2.8418z"/></svg>""",
    guidelines=None,
    license=None,
)
