from simpleicons.icon import Icon
okta_icon= Icon(
    title="Okta",
    slug="okta",
    hex="007DC1",
    source="https://www.okta.com/press-room/media-assets/",
    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>Okta</title><path d="M12 0C5.389 0 0 5.35 0 12s5.35 12 12 12 12-5.35 12-12S18.611 0 12 0zm0 18c-3.325 0-6-2.675-6-6s2.675-6 6-6 6 2.675 6 6-2.675 6-6 6z"/></svg>""",
    guidelines='https://www.okta.com/terms-of-use-for-okta-content/',
    license=None,
)
