from simpleicons.icon import Icon
verizon_icon= Icon(
    title="Verizon",
    slug="verizon",
    hex="CD040B",
    source="https://www.verizondigitalmedia.com/about/logo-usage/",
    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>Verizon</title><path d="M18.302 0H22v.003L10.674 24H7.662L2 12h3.727l3.449 7.337z"/></svg>""",
    guidelines=None,
    license=None,
)
