from simpleicons.icon import Icon
macys_icon= Icon(
    title="Macy’s",
    slug="macys",
    hex="E21A2C",
    source="https://www.macysinc.com/news-media/media-assets",
    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>Macy’s</title><path d="M12.015.624L9.19 9.293H0l7.445 5.384-2.819 8.673L12 17.986l7.422 5.393-2.835-8.713L24 9.292h-9.162L12.015.622v.002z"/></svg>""",
    guidelines=None,
    license=None,
)
