from simpleicons.icon import Icon
artixlinux_icon= Icon(
    title="Artix Linux",
    slug="artixlinux",
    hex="10A0CC",
    source="https://gitea.artixlinux.org/artix/artwork/src/commit/256432e3d06b3e9024bfd6912768e80281ea3746/icons/logo-gray.svg",
    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>Artix Linux</title><path d="M12 0L7.873 8.462l11.358 6.363zM6.626 11.018L.295 24l18.788-7.762zm13.846 6.352l-5.926 3.402L23.706 24Z"/></svg>""",
    guidelines=None,
    license=None,
)
