from simpleicons.icon import Icon
micropython_icon= Icon(
    title="MicroPython",
    slug="micropython",
    hex="2B2728",
    source="https://commons.wikimedia.org/wiki/File:MicroPython_new_logo.svg",
    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>MicroPython</title><path d="M0 0h11.509v18.737h.982V0H24v24h-5.263V5.263h-.983V24H6.246V5.263l-.983.035V24H0zm22.246 19.509h-1.404v2.386h1.404z"/></svg>""",
    guidelines=None,
    license=None,
)
