from simpleicons.icon import Icon
flutter_icon= Icon(
    title="Flutter",
    slug="flutter",
    hex="02569B",
    source="https://flutter.dev/brand",
    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>Flutter</title><path d="M14.314 0L2.3 12 6 15.7 21.684.013h-7.357zm.014 11.072L7.857 17.53l6.47 6.47H21.7l-6.46-6.468 6.46-6.46h-7.37z"/></svg>""",
    guidelines='https://flutter.dev/brand',
    license=None,
)
