from simpleicons.icon import Icon
shotcut_icon= Icon(
    title="Shotcut",
    slug="shotcut",
    hex="115C77",
    source="https://shotcut.com/media/",
    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>Shotcut</title><path d="M0 0h6.667v24H0v-.889h5.778V.889H0V0zm7.556 0v24H24v-.889H8.444V.889H24V0H7.556zm1.388 22.611H24V1.389H8.944v21.222zM5.278 1.389H0v21.222h5.278V1.389z"/></svg>""",
    guidelines=None,
    license=None,
)
