from simpleicons.icon import Icon
minutemailer_icon= Icon(
    title="Minutemailer",
    slug="minutemailer",
    hex="30B980",
    source="https://minutemailer.com",
    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>Minutemailer</title><path d="M17.187 19.181L24 4.755 0 12.386l9.196 1.963.043 4.896 2.759-2.617-2.147-2.076 7.336 4.63z"/></svg>""",
    guidelines=None,
    license=None,
)
