from simpleicons.icon import Icon
chartmogul_icon= Icon(
    title="ChartMogul",
    slug="chartmogul",
    hex="13324B",
    source="https://chartmogul.com/company/",
    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>ChartMogul</title><path d="M10.621 19.89V8.75L2.867 19.89H0V4.11h2.758v11.112l7.754-11.113h2.867v11.14L21.16 4.11H24v15.782h-2.73V8.75l-7.755 11.14Z"/></svg>""",
    guidelines=None,
    license=None,
)
