from simpleicons.icon import Icon
ycombinator_icon= Icon(
    title="Y Combinator",
    slug="ycombinator",
    hex="F0652F",
    source="https://www.ycombinator.com/press/",
    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>Y Combinator</title><path d="M0 24V0h24v24H0zM6.951 5.896l4.112 7.708v5.064h1.583v-4.972l4.148-7.799h-1.749l-2.457 4.875c-.372.745-.688 1.434-.688 1.434s-.297-.708-.651-1.434L8.831 5.896h-1.88z"/></svg>""",
    guidelines=None,
    license=None,
)
