from simpleicons.icon import Icon
futurelearn_icon= Icon(
    title="FutureLearn",
    slug="futurelearn",
    hex="DE00A5",
    source="https://www.futurelearn.com/",
    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>FutureLearn</title><path d="M22.081.61v7.566h-7.223v6.661H7.566v6.634H0v1.92h9.471v-6.649h7.306v-6.66H24V.61Z"/></svg>""",
    guidelines=None,
    license=None,
)
