from simpleicons.icon import Icon
slashdot_icon= Icon(
    title="Slashdot",
    slug="slashdot",
    hex="026664",
    source="https://commons.wikimedia.org/wiki/File:Slashdot_wordmark_and_logo.svg",
    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>Slashdot</title><path d="M19.777 0L7.037 24H1.868L14.605 0h5.172zm2.354 19.801c0 2.268-1.841 4.105-4.109 4.105s-4.107-1.838-4.107-4.105 1.839-4.107 4.107-4.107 4.109 1.839 4.109 4.107z"/></svg>""",
    guidelines=None,
    license=None,
)
