from simpleicons.icon import Icon
accenture_icon= Icon(
    title="Accenture",
    slug="accenture",
    hex="A100FF",
    source="https://www.accenture.com/",
    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>Accenture</title><path d="M23.297 14.74L.434 24v-5.263L16.8 12.11l6.497 2.631zm.27-5.371L.433 0v5.263l23.132 9.368V9.37z"/></svg>""",
    guidelines=None,
    license=None,
)
