from simpleicons.icon import Icon
bandsintown_icon= Icon(
    title="Bandsintown",
    slug="bandsintown",
    hex="00CEC8",
    source="https://corp.bandsintown.com/media-library",
    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>Bandsintown</title><path d="M18.783 0H24v12h-5.217V0zm-6.261 5h5.217v7h-5.217V5zM6.26 5h5.217v7H6.261V5zM24 24H0V0h5.217v19h13.566v-1H6.26v-5H24v11Z"/></svg>""",
    guidelines=None,
    license=None,
)
