from simpleicons.icon import Icon
pytorchlightning_icon= Icon(
    title="PyTorch Lightning",
    slug="pytorchlightning",
    hex="792EE5",
    source="https://github.com/PyTorchLightning/pytorch-lightning/blob/a584196abf820179adb0758ef67ddae91c44e7bc/docs/source/_static/images/icon.svg",
    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>PyTorch Lightning</title><path d="M12 0L1.75 6v12L12 24l10.25-6V6zm-1.775 18l1.08-4.657-2.428-2.397L13.79 6l-1.082 4.665 2.414 2.384z"/></svg>""",
    guidelines=None,
    license=None,
)
