from simpleicons.icon import Icon
platformdotsh_icon= Icon(
    title="Platform.sh",
    slug="platformdotsh",
    hex="1A182A",
    source="https://platform.sh/logos/",
    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>Platform.sh</title><path d="M24 0H0v9.541h24V0zM24 20.755H0V24h24v-3.245zM0 12.618h24v4.892H0v-4.892z"/></svg>""",
    guidelines=None,
    license=None,
)
