from simpleicons.icon import Icon
pinboard_icon= Icon(
    title="Pinboard",
    slug="pinboard",
    hex="0000FF",
    source="https://commons.wikimedia.org/wiki/File:Feedbin-Icon-share-pinboard.svg",
    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>Pinboard</title><path d="M13.352 14.585l-4.509 4.614.72-4.062L3.428 7.57 0 7.753 7.58 0v2.953l7.214 6.646 4.513-1.105-4.689 4.982L24 24l-10.648-9.415z"/></svg>""",
    guidelines=None,
    license=None,
)
