from simpleicons.icon import Icon
pandora_icon= Icon(
    title="Pandora",
    slug="pandora",
    hex="224099",
    source="https://www.pandoraforbrands.com/",
    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>Pandora</title><path d="M1.882 0v24H8.32a1.085 1.085 0 001.085-1.085v-4.61h1.612c7.88 0 11.103-4.442 11.103-9.636C22.119 2.257 17.247 0 12.662 0H1.882Z"/></svg>""",
    guidelines=None,
    license=None,
)
