from simpleicons.icon import Icon
flipboard_icon= Icon(
    title="Flipboard",
    slug="flipboard",
    hex="E12828",
    source="https://about.flipboard.com/brand-guidelines",
    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>Flipboard</title><path d="M0 0v24h24V0H0zm19.2 9.6h-4.8v4.8H9.6v4.8H4.8V4.8h14.4v4.8z"/></svg>""",
    guidelines=None,
    license=None,
)
