from simpleicons.icon import Icon
istio_icon= Icon(
    title="Istio",
    slug="istio",
    hex="466BB0",
    source="https://github.com/istio/istio/blob/5a047251817eb2523af297607b7614120812e47a/logo/istio-bluelogo-whitebackground-unframed.svg",
    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>Istio</title><path d="M4 21 20 21 10 24zM4 20 10 19 10 8zM11 19 20 20 11 0z"/></svg>""",
    guidelines=None,
    license=None,
)
