from simpleicons.icon import Icon
googlehangouts_icon= Icon(
    title="Google Hangouts",
    slug="googlehangouts",
    hex="0C9D58",
    source="https://upload.wikimedia.org/wikipedia/commons/e/ee/Hangouts_icon.svg",
    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>Google Hangouts</title><path d="M12 0C6.2 0 1.5 4.7 1.5 10.5c0 5.5 5 10 10.5 10V24c6.35-3.1 10.5-8.2 10.5-13.5C22.5 4.7 17.8 0 12 0zm-.5 12c0 1.4-.9 2.5-2 2.5V12H7V7.5h4.5V12zm6 0c0 1.4-.9 2.5-2 2.5V12H13V7.5h4.5V12z"/></svg>""",
    guidelines=None,
    license=None,
)
