from simpleicons.icon import Icon
dwm_icon= Icon(
    title="dwm",
    slug="dwm",
    hex="1177AA",
    source="https://dwm.suckless.org",
    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>dwm</title><path d="M0 11h6V7h2v8h2v-4h2v4h2v-4h10v6h-2v-4h-2v4h-2v-4h-2v4H2v-2h4v-2H2v4H0z"/></svg>""",
    guidelines=None,
    license=None,
)
