from simpleicons.icon import Icon
purism_icon= Icon(
    title="Purism",
    slug="purism",
    hex="2D2D2D",
    source="https://puri.sm/pr/images/",
    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>Purism</title><path d="M24 19.588H0V4.412h24zM2.824 16.765h18.352v-9.53H2.824Z"/></svg>""",
    guidelines=None,
    license=None,
)
