from simpleicons.icon import Icon
stitcher_icon= Icon(
    title="Stitcher",
    slug="stitcher",
    hex="000000",
    source="https://partners.stitcher.com/",
    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>Stitcher</title><path d="M19.59 8.516H24v6.928h-4.41zM0 8.854h4.41v7.803H0zm4.914-1.328h4.388v8.572H4.914zm4.892.725h4.388v8.81H9.806zm4.892-1.312h4.388v9.158h-4.388Z"/></svg>""",
    guidelines=None,
    license=None,
)
