from simpleicons.icon import Icon
azuredevops_icon= Icon(
    title="Azure DevOps",
    slug="azuredevops",
    hex="0078D7",
    source="http://azure.com/devops",
    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>Azure DevOps</title><path d="M0 8.877L2.247 5.91l8.405-3.416V.022l7.37 5.393L2.966 8.338v8.225L0 15.707zm24-4.45v14.651l-5.753 4.9-9.303-3.057v3.056l-5.978-7.416 15.057 1.798V5.415z"/></svg>""",
    guidelines=None,
    license=None,
)
