from simpleicons.icon import Icon
tvtime_icon= Icon(
    title="TV Time",
    slug="tvtime",
    hex="FFD400",
    source="https://www.tvtime.com/",
    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>TV Time</title><path d="M0 0v24h24V0zm4.8 4.8h14.4v4.8h-4.8v9.6H9.6V9.6H4.8Z"/></svg>""",
    guidelines=None,
    license=None,
)
