from simpleicons.icon import Icon
playcanvas_icon= Icon(
    title="PlayCanvas",
    slug="playcanvas",
    hex="E05F2C",
    source="https://playcanvas.com/",
    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>PlayCanvas</title><path d="M6.115 0l-.002 3.414 5.823 3.41-5.82 3.414-.003 3.412 11.774-6.826zm11.77 10.35L6.113 17.174 17.887 24l-.002-3.414-5.82-3.412 5.822-3.412z"/></svg>""",
    guidelines=None,
    license=None,
)
