from simpleicons.icon import Icon
virustotal_icon= Icon(
    title="VirusTotal",
    slug="virustotal",
    hex="394EFF",
    source="https://www.virustotal.com/",
    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>VirusTotal</title><path d="M10.87 12L0 22.68h24V1.32H0zm10.73 8.52H5.28l8.637-8.448L5.28 3.48H21.6z"/></svg>""",
    guidelines=None,
    license=None,
)
