from simpleicons.icon import Icon
expertsexchange_icon= Icon(
    title="Experts Exchange",
    slug="expertsexchange",
    hex="00AAE7",
    source="https://www.experts-exchange.com/",
    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>Experts Exchange</title><path d="M7.28.9H0L8.36 12 0 23.1h7.28L15.64 12zM24 .9h-7.28l-2.3 3.06 3.64 4.82zM14.42 20.05l2.3 3.05H24l-5.94-7.88z"/></svg>""",
    guidelines=None,
    license=None,
)
