from simpleicons.icon import Icon
alitalia_icon= Icon(
    title="Alitalia",
    slug="alitalia",
    hex="006643",
    source="https://www.alitalia.com/it_it/fly-alitalia/in-flight/ulisse-magazine.html",
    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>Alitalia</title><path d="M5.429 20.551H0l14.257-14.87c1.622-1.765 2.878-2.232 4.686-2.232H24L21.602 20.55h-4.17L19.49 5.907M15.7 20.551l1.384-9.842-9.457 9.842Z"/></svg>""",
    guidelines=None,
    license=None,
)
