from simpleicons.icon import Icon
xilinx_icon= Icon(
    title="Xilinx",
    slug="xilinx",
    hex="E01F27",
    source="https://www.xilinx.com",
    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>Xilinx</title><path d="M8 18l5.241 6H5.586L.345 18l5.241-6L.345 6l5.241-6h7.655L8 6l5.241 6L8 18zM23.655 0H13.241l5.241 6 5.173-6zM13.241 24h10.414l-5.172-6-5.242 6z"/></svg>""",
    guidelines=None,
    license=None,
)
