from simpleicons.icon import Icon
kibana_icon= Icon(
    title="Kibana",
    slug="kibana",
    hex="005571",
    source="https://www.elastic.co/brand",
    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>Kibana</title><path d="M2.625 0v21.591L21.375 0zm10.864 12.47L3.477 24h17.522a18.755 18.755 0 0 0-7.51-11.53z"/></svg>""",
    guidelines=None,
    license=None,
)
