from simpleicons.icon import Icon
datocms_icon= Icon(
    title="DatoCMS",
    slug="datocms",
    hex="FF7751",
    source="https://www.datocms.com/company/brand-assets",
    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>DatoCMS</title><path d="M12 0H.076v24H12c5.964 0 11.924-5.373 11.924-11.998C23.924 5.376 17.963 0 12 0zm0 17.453a5.453 5.453 0 115.455-5.451A5.45 5.45 0 0112 17.452z"/></svg>""",
    guidelines='https://www.datocms.com/company/brand-assets',
    license=None,
)
