from simpleicons.icon import Icon
spreadshirt_icon= Icon(
    title="Spreadshirt",
    slug="spreadshirt",
    hex="00B2A5",
    source="https://www.spreadshirt.ie/",
    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>Spreadshirt</title><path d="M12 6.306L7.796 2.102 0 9.898l12 12 12-12-7.796-7.796zm0 12L3.592 9.898l4.204-4.204L12 9.898l4.184-4.184 4.204 4.204"/></svg>""",
    guidelines=None,
    license=None,
)
