from simpleicons.icon import Icon
airfrance_icon= Icon(
    title="Air France",
    slug="airfrance",
    hex="002157",
    source="https://www.airfrance.fr/",
    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>Air France</title><path d="M13.776 3.9L5.184 16.332C4.051 17.969 2.208 19.548 0 19.721v.379h9.552c2.544 0 4.397-1.656 5.616-3.48L24 3.9Z"/></svg>""",
    guidelines=None,
    license=None,
)
