from simpleicons.icon import Icon
codeclimate_icon= Icon(
    title="Code Climate",
    slug="codeclimate",
    hex="000000",
    source="https://codeclimate.com/github/codeclimate/python-test-reporter/badges/",
    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>Code Climate</title><path d="M16.125 5.272l-4.511 4.475 2.684 2.659 1.827-1.813 5.19 5.145L24 13.079zM8.13 8.265L0 16.066l2.772 2.662 5.357-5.145 5.357 5.145 2.772-2.662z"/></svg>""",
    guidelines=None,
    license=None,
)
