from simpleicons.icon import Icon
osano_icon= Icon(
    title="Osano",
    slug="osano",
    hex="7764FA",
    source="https://www.osano.com/company/assets",
    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>Osano</title><path d="M12 6.091A5.909 5.909 0 1017.909 12 5.91 5.91 0 0012 6.091M12 0A12 12 0 110 12 12 12 0 0112 0z"/></svg>""",
    guidelines=None,
    license=None,
)
