from simpleicons.icon import Icon
terraform_icon= Icon(
    title="Terraform",
    slug="terraform",
    hex="7B42BC",
    source="https://www.hashicorp.com/brand",
    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>Terraform</title><path d="M1.44 0v7.575l6.561 3.79V3.787zm21.12 4.227l-6.561 3.791v7.574l6.56-3.787zM8.72 4.23v7.575l6.561 3.787V8.018zm0 8.405v7.575L15.28 24v-7.578z"/></svg>""",
    guidelines='https://www.hashicorp.com/brand',
    license=None,
)
