from simpleicons.icon import Icon
kotlin_icon= Icon(
    title="Kotlin",
    slug="kotlin",
    hex="0095D5",
    source="https://resources.jetbrains.com/storage/products/kotlin/docs/kotlin_logos.zip",
    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>Kotlin</title><path d="M0 24V13.848L13.505 0H24L0 24zM0 0v12.672L12.05 0H0zm1.335 24H24L12.699 12.618 1.335 24z"/></svg>""",
    guidelines='https://www.jetbrains.com/company/brand/',
    license=None,
)
