from simpleicons.icon import Icon
hyper_icon= Icon(
    title="Hyper",
    slug="hyper",
    hex="000000",
    source="https://hyper.is/",
    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>Hyper</title><path d="M13.565 17.91H24v1.964H13.565zm-3.201-5.09l-9.187 8.003 2.86-7.004L0 11.179l9.187-8.002-3.11 7.451z"/></svg>""",
    guidelines=None,
    license=None,
)
