from simpleicons.icon import Icon
netapp_icon= Icon(
    title="NetApp",
    slug="netapp",
    hex="0067C5",
    source="http://www.netapp.com/",
    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>NetApp</title><path d="M0 2v20h9.33V10h5.34v12H24V2Z"/></svg>""",
    guidelines='https://www.netapp.com/company/legal/trademark-guidelines/',
    license=None,
)
