from simpleicons.icon import Icon
deutschebank_icon= Icon(
    title="Deutsche Bank",
    slug="deutschebank",
    hex="0018A8",
    source="https://www.db.com/",
    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>Deutsche Bank</title><path d="M3.375 3.375v17.25h17.25V3.375H3.375zM0 0h24v24H0V0zm5.25 18.225 9.15-12.45h4.35L9.6 18.225H5.25z"/></svg>""",
    guidelines=None,
    license=None,
)
