from simpleicons.icon import Icon
anydesk_icon= Icon(
    title="AnyDesk",
    slug="anydesk",
    hex="EF443B",
    source="https://anydesk.com/",
    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>AnyDesk</title><path d="M8.322 3.677L0 12l8.322 8.323L16.645 12zm7.371.01l-1.849 1.85 6.49 6.456-6.49 6.49 1.85 1.817L24 11.993Z"/></svg>""",
    guidelines=None,
    license=None,
)
