from simpleicons.icon import Icon
delicious_icon= Icon(
    title="del.icio.us",
    slug="delicious",
    hex="0000FF",
    source="http://del.icio.us/",
    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>del.icio.us</title><path d="M12 12H0v12h12V12zM24 0H12v12h12V0z"/></svg>""",
    guidelines=None,
    license=None,
)
