from simpleicons.icon import Icon
aframe_icon= Icon(
    title="A-Frame",
    slug="aframe",
    hex="EF2D5E",
    source="https://aframe.io/docs/",
    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>A-Frame</title><path d="M17.37 17.07H6.57L4.24 24H3.01l8.23-24h1.52l8.23 24h-1.3zm-.39-1.13l-5-14.96-5.03 14.98h10.03Z"/></svg>""",
    guidelines=None,
    license=None,
)
