from simpleicons.icon import Icon
mitsubishi_icon= Icon(
    title="Mitsubishi",
    slug="mitsubishi",
    hex="E60012",
    source="https://www.mitsubishi.com/",
    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>Mitsubishi</title><path d="M8 22.38H0l4-6.92h8zm8 0h8l-4-6.92h-8zm0-13.84l-4-6.92-4 6.92 4 6.92Z"/></svg>""",
    guidelines=None,
    license=None,
)
