from simpleicons.icon import Icon
feathub_icon= Icon(
    title="FeatHub",
    slug="feathub",
    hex="9B9B9B",
    source="http://feathub.com/",
    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>FeatHub</title><path d="M8.571 0v6.857h6.858V0zM0 8.571v6.858h24V8.57zm8.571 8.572V24h6.858v-6.857z"/></svg>""",
    guidelines=None,
    license=None,
)
