from simpleicons.icon import Icon
docusign_icon= Icon(
    title="DocuSign",
    slug="docusign",
    hex="FFCC22",
    source="https://github.com/simple-icons/simple-icons/issues/1098",
    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>DocuSign</title><path d="M9.517 3.31h4.966v6.621h3.31L12 16.552 6.207 9.931h3.31V3.31zM0 19.034h24v1.655H0v-1.655z"/></svg>""",
    guidelines=None,
    license=None,
)
