from simpleicons.icon import Icon
vuedotjs_icon= Icon(
    title="Vue.js",
    slug="vuedotjs",
    hex="4FC08D",
    source="https://github.com/vuejs/art",
    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>Vue.js</title><path d="M24,1.61H14.06L12,5.16,9.94,1.61H0L12,22.39ZM12,14.08,5.16,2.23H9.59L12,6.41l2.41-4.18h4.43Z"/></svg>""",
    guidelines='https://github.com/vuejs/art/blob/master/README.md',
    license={'type': 'custom', 'url': 'https://github.com/vuejs/art/blob/master/README.md'},
)
