from simpleicons.icon import Icon
razorpay_icon= Icon(
    title="Razorpay",
    slug="razorpay",
    hex="0C2451",
    source="https://razorpay.com/newsroom/brand-assets/",
    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>Razorpay</title><path d="M22.436 0l-11.91 7.773-1.174 4.276 6.625-4.297L11.65 24h4.391l6.395-24zM14.26 10.098L3.389 17.166 1.564 24h9.008l3.688-13.902Z"/></svg>""",
    guidelines='https://razorpay.com/newsroom/brand-assets/',
    license=None,
)
