from simpleicons.icon import Icon
bbciplayer_icon= Icon(
    title="BBC iPlayer",
    slug="bbciplayer",
    hex="F54997",
    source="https://www.bbc.co.uk/iplayer",
    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>BBC iPlayer</title><path d="M8.315 0H2.382v6.022h5.933V3.506l9.618 8.45-9.618 8.538V8.99H2.382V24h5.933l13.303-12.045Z"/></svg>""",
    guidelines=None,
    license=None,
)
