from simpleicons.icon import Icon
bulma_icon= Icon(
    title="Bulma",
    slug="bulma",
    hex="00D1B2",
    source="https://github.com/jgthms/bulma/",
    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>Bulma</title><path d="M11.25 0l-6 6 -1.5 10.5 7.5 7.5 9 -6 -6 -6 4.5 -4.5 -7.5 -7.5Z"/></svg>""",
    guidelines=None,
    license=None,
)
