from simpleicons.icon import Icon
eclipseche_icon= Icon(
    title="Eclipse Che",
    slug="eclipseche",
    hex="525C86",
    source="https://www.eclipse.org/che/",
    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>Eclipse Che</title><path d="M12 0L1.604 6.021v7.452L12 7.494l3.941 2.254 6.455-3.727zm10.396 10.527L12 16.506l-7.334-4.217-3.062 1.76v3.93L12 24l10.396-6.021z"/></svg>""",
    guidelines=None,
    license=None,
)
