from simpleicons.icon import Icon
beats_icon= Icon(
    title="Beats",
    slug="beats",
    hex="005571",
    source="https://www.elastic.co/brand",
    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>Beats</title><path d="M2.625 0v15h8.25a7.5 7.5 0 0 0 0-15zm17.016 11.705c-1.571 3.261-4.91 5.517-8.766 5.517h-8.25V24h11.25a7.5 7.5 0 0 0 5.766-12.295z"/></svg>""",
    guidelines=None,
    license=None,
)
