from simpleicons.icon import Icon
bandcamp_icon= Icon(
    title="Bandcamp",
    slug="bandcamp",
    hex="408294",
    source="https://bandcamp.com/buttons",
    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>Bandcamp</title><path d="M0 18.75l7.437-13.5H24l-7.438 13.5H0z"/></svg>""",
    guidelines=None,
    license=None,
)
