from simpleicons.icon import Icon
squareenix_icon= Icon(
    title="Square Enix",
    slug="squareenix",
    hex="ED1C24",
    source="https://www.square-enix.com/",
    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>Square Enix</title><path d="M1.723 0v24h20.554v-4.496H7.037V4.088h15.006V0zm9.751 9.46v4.497h8.584V9.459z"/></svg>""",
    guidelines=None,
    license=None,
)
