from simpleicons.icon import Icon
adonisjs_icon= Icon(
    title="AdonisJS",
    slug="adonisjs",
    hex="220052",
    source="https://adonisjs.com/",
    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>AdonisJS</title><path d="M13.333 1.333l-.596 1.193-2.404 4.807L8 2.667l-8 16h4.667l-2 4H24zm0 2.982l8.51 17.018H4.823l1.334-2.666H16l-4.922-9.843Z"/></svg>""",
    guidelines=None,
    license=None,
)
