from simpleicons.icon import Icon
reverbnation_icon= Icon(
    title="ReverbNation",
    slug="reverbnation",
    hex="E43526",
    source="https://www.reverbnation.com",
    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>ReverbNation</title><path d="M24 9.324l-9.143-.03L11.971.57 9.143 9.294 0 9.324h.031l7.367 5.355-2.855 8.749h.029l7.459-5.386 7.396 5.386-2.855-8.73L24 9.315"/></svg>""",
    guidelines=None,
    license=None,
)
