from simpleicons.icon import Icon
koding_icon= Icon(
    title="Koding",
    slug="koding",
    hex="00B057",
    source="https://koding.com/About",
    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>Koding</title><path d="M.8 0H23v6H1V0zm0 9H18v6H.7V9zm0 9H23v6H1v-6z"/></svg>""",
    guidelines=None,
    license=None,
)
