from simpleicons.icon import Icon
vectorlogozone_icon= Icon(
    title="Vector Logo Zone",
    slug="vectorlogozone",
    hex="184D66",
    source="https://www.vectorlogo.zone/",
    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>Vector Logo Zone</title><path d="M19.458 0l-5.311 2.024 1.989.534-4.847 16.085-4.867-16.25H1.48L8.974 24h4.645l7.043-20.226 1.858.499Z"/></svg>""",
    guidelines=None,
    license=None,
)
