from simpleicons.icon import Icon
vuetify_icon= Icon(
    title="Vuetify",
    slug="vuetify",
    hex="1867C0",
    source="https://vuetifyjs.com/",
    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>Vuetify</title><path d="M7.094 0L12 11.596 16.906 0H7.094zM1.5 3.5L12 24 22.5 3.5H17L12 15 7 3.5z"/></svg>""",
    guidelines=None,
    license=None,
)
