from simpleicons.icon import Icon
zotero_icon= Icon(
    title="Zotero",
    slug="zotero",
    hex="CC2936",
    source="https://www.zotero.org/support/brand",
    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>Zotero</title><path d="M21.231 2.462 7.18 20.923h14.564V24H2.256v-2.462L16.308 3.076H2.975V0h18.256v2.462z"/></svg>""",
    guidelines=None,
    license=None,
)
