from simpleicons.icon import Icon
adobe_icon= Icon(
    title="Adobe",
    slug="adobe",
    hex="FF0000",
    source="https://www.adobe.com/",
    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>Adobe</title><path d="M13.966 22.624l-1.69-4.281H8.122l3.892-9.144 5.662 13.425zM8.884 1.376H0v21.248zm15.116 0h-8.884L24 22.624Z"/></svg>""",
    guidelines=None,
    license=None,
)
