from simpleicons.icon import Icon
pagekit_icon= Icon(
    title="Pagekit",
    slug="pagekit",
    hex="212121",
    source="https://pagekit.com/logo-guide",
    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>Pagekit</title><path d="M2.401 0v24h9.6v-3.527H5.929V3.526h12.146v13.421h-6.073v3.525H21.6V0H2.401z"/></svg>""",
    guidelines='https://pagekit.com/logo-guide',
    license=None,
)
